@@ -2,10 +2,12 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from .sale import *
+
+from . import sale
 
 
 def register():
     Pool.register(
-        Sale,
+        sale.Sale,
+        sale.Line,
         module='sale_stock_quantity', type_='model')
